<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit0607aff10648ef74c8ea6dd76ad3cc2d
{
    public static $prefixLengthsPsr4 = array (
        'R' => 
        array (
            'RegularLabs\\Plugin\\System\\AdvancedModules\\' => 42,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'RegularLabs\\Plugin\\System\\AdvancedModules\\' => 
        array (
            0 => __DIR__ . '/../..' . '/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit0607aff10648ef74c8ea6dd76ad3cc2d::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit0607aff10648ef74c8ea6dd76ad3cc2d::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit0607aff10648ef74c8ea6dd76ad3cc2d::$classMap;

        }, null, ClassLoader::class);
    }
}
